@@ -1,8 +1,8 @@
 # Variables to be shared across modules
 
-dofile_basename = None
-filename = None
-format = None
+dofile_basename = ''
+filename = ''
+format = ''
 encoding = ''
 
 _log = ''
@@ -44,8 +44,8 @@ style = {
 }
 
 # Regular expressions for inline tags:
-inline_tag_begin = r"""(?P<begin>(^|[(\s~>{!-]|^__|&[mn]dash;))"""
-inline_tag_end = r"""(?P<end>($|[.,?!;:)<}!'\s~\[<&;-]))"""
+inline_tag_begin =  r"(?P<begin>(^|\" |[(\s~>{!-]|^__|&[mn]dash;))"
+inline_tag_end =    r"(?P<end>($|\" |[.,?!;:)<}!'\s~\[<&;-]))"
 
 # Admonitions
 admons = 'notice', 'summary', 'warning', 'question', 'block'
@@ -248,7 +248,167 @@ locale_dict = dict(
         # References
         'Filename': u'اسم_الملف',
         'Filenames': u'أسماء_الملفات',
-    }
+    },
+    French={
+        'locale': 'fr_FR.UTF-8', # français
+        'latex package': 'french',
+        'toc': u'Table des matières',
+        'Contents': 'Sommaire',
+        'Figure': 'Figure',
+        'Movie': u'Vidéo',
+        'list of': 'Liste des',
+        'and': 'et',
+        'Exercise': 'Exercice',
+        'Project': 'Projet',
+        'Problem': u'Problème',
+        'Example': 'Exemple',
+        'Exercises': 'Exercices',
+        'Projects': 'Projets',
+        'Problems': u'Problèmes',
+        'Examples': 'Exemples',
+        'Preface': u'Préface',
+        'Abstract': u'Résumé',
+        'Summary': u'Résumé',
+        'summary': u'résumé',
+        'hint': 'Indication',
+        'question': u'question',
+        'notice': 'note',
+        'warning': 'avertissement',
+        'remarks': 'remarque',
+        'index': 'Index',
+        'Solution': 'Solution',  # In exercises
+        'Answer': u'Réponse',
+        'Hint': 'Indication',
+        'Filename': 'Nom de fichier',
+        'Filenames': 'Noms de fichier',
+        'question_prefix': 'Question:', # question in multiple-choice quiz
+        'choice_prefix': 'Alternative', # choice in multiple-choice quiz
+        },
+    Dutch={
+        # Nederlands
+        'locale': 'nl_NL.UTF-8',
+        'latex package': 'dutch',
+        'aspell_dictionary' : 'dutch', # with aspell, this is an alias for 'en_US'
+        'toc': 'Inhoudsopgave',
+        'Contents': 'Inhoud',
+        'Figure': 'Figuur',
+        'Movie': 'Film',
+        'list of': 'Lijst met',
+        'and': 'en',
+        'Exercise': 'Oefening',
+        'Project': 'Project',
+        'Problem': 'Probleem',
+        'Example': 'Voorbeeld',
+        'Projects': 'Projecten',
+        'Problems': 'Problemen',
+        'Examples': 'Voorbeelden',
+        'Preface': 'Voorwoord',
+        'Abstract': 'Abstract',
+        'Summary': 'Samenvatting',
+        # Admons
+        'summary': 'samenvatting',
+        'hint': 'hint',
+        'question': 'Vraag',
+        'notice': 'opmerking',
+        'warning': 'waarschuving',
+        # box, quote are silent wrt title
+        'remarks': 'opmerkingen', # In exercises
+        # Exercise headings
+        'Solution': 'Oplossing',
+        'Answer': 'antwoord',
+        'Hint': 'Hint',
+        # At the end (in Sphinx)
+        'index': 'Inhoudsopgave',
+        # References
+        'Filename': 'Bestandsnaam',
+        'Filenames': 'Bestandsnamen',
+        # Quiz
+        'question_prefix': 'Vraag:',    # question in multiple-choice quiz
+        'choice_prefix': 'Alternatief', # choice in multiple-choice quiz
+    },
+    Italian={
+        'locale': 'it_IT.UTF-8',
+        'latex package': 'italian',
+        'aspell_dictionary' : 'italian',
+        'toc': 'Indice',
+        'Contents': 'Contenuto',
+        'Figure': 'Figura',
+        'Movie': 'Video',
+        'list of': 'Lista con',
+        'and': 'e',
+        'Exercise': 'Esercizio',
+        'Project': 'Progetto',
+        'Problem': 'Problema',
+        'Example': 'Esempio',
+        'Projects': 'Progetto',
+        'Problems': 'Problemi',
+        'Examples': 'Esempi',
+        'Preface': 'Prefazione',
+        'Abstract': 'Abstract',
+        'Summary': 'Riassunto',
+        # Admons
+        'summary': 'sommario',
+        'hint': 'suggerimento',
+        'question': 'domanda',
+        'notice': 'NB',
+        'warning': 'avvertimento',
+        # box, quote are silent wrt title
+        'remarks': 'osservazioni', # In exercises
+        # Exercise headings
+        'Solution': 'Soluzione',
+        'Answer': 'Risposta',
+        'Hint': 'Suggerimento',
+        # At the end (in Sphinx)
+        'index': 'Indice',
+        # References
+        'Filename': 'Nome del file',
+        'Filenames': 'Nomi dei file',
+        # Quiz
+        'question_prefix': 'Domanda:',  # question in multiple-choice quiz
+        'choice_prefix': 'Alternativa', # choice in multiple-choice quiz
+        },
+    Spanish={
+        # Spanish, Spain
+        'locale': 'es_ES.UTF-8',
+        'latex package': 'spanish',
+        'aspell_dictionary' : 'spanish',
+        'toc': 'Tabla de contenido',
+        'Contents': 'Contenido',
+        'Figure': 'Figura',
+        'Movie': 'Video',
+        'list of': 'Lista de',
+        'and': 'y',
+        'Exercise': 'Ejercicio',
+        'Project': 'Proyecto',
+        'Problem': 'Problema',
+        'Example': 'Ejemplo',
+        'Projects': 'Proyecto',
+        'Problems': 'Problemas',
+        'Examples': 'Ejemplos',
+        'Preface': 'Prefacio',
+        'Abstract': 'Abstracta',
+        'Summary': 'Resumen',
+        # Admons
+        'summary': 'resumen',
+        'hint': 'indicio',
+        'question': 'pregunta',
+        'notice': 'nota',
+        'warning': 'advertencia',
+        # box, quote are silent wrt title
+        'remarks': 'comentarios', # In exercises
+        # Exercise headings
+        'Solution': 'Soluciones',
+        'Answer': 'Respuesta',
+        'Hint': 'Indicios',
+        # At the end (in Sphinx)
+        'index': 'Índice',
+        # References
+        'Filename': 'Nombre del archivo',
+        'Filenames': 'Nombres de los archivos',
+        # Quiz
+        'question_prefix': 'Pregunta:', # question in multiple-choice quiz
+        'choice_prefix': 'Alternativa', # choice in multiple-choice quiz
+        }
     )
 # Let English be an alias for American
 locale_dict['English'] = locale_dict['American'].copy()
