@@ -1,5 +1,5 @@
 #!/bin/bash -x
-set -x
+#set -x
 #export PS4='+ l.${LINENO}: ${FUNCNAME[0]:+${FUNCNAME[0]}(): }'
 function system {
   "$@"
@@ -38,20 +38,18 @@ EOF
 
 system doconce spellcheck -d .dict4spell.txt _testdoc.do.txt
 
-rawgit="--html_raw_github_url=raw.github"
-
 system doconce jupyterbook testdoc --show_titles --sep=section --dest=$PWD --dest_toc=$PWD --examples_as_exercises --allow_refs_to_external_docs
 
 system doconce jupyterbook testdoc --show_titles --sep=section --sep_section=subsection --titles=README --examples_as_exercises --allow_refs_to_external_docs 
 
 system doconce jupyterbook testdoc --show_titles --sep=section --sep_section=subsection --dest=$PWD --dest_toc=$PWD --examples_as_exercises --allow_refs_to_external_docs
 
-system doconce format html testdoc --wordpress  --examples_as_exercises --html_exercise_icon=question_blue_on_white1.png --html_exercise_icon_width=80 --figure_prefix="https://raw.github.com/hplgit/doconce/master/test/" --movie_prefix="https://raw.github.com/hplgit/doconce/master/test/" --html_links_in_new_window --cite_doconce $rawgit
+system doconce format html testdoc --wordpress  --examples_as_exercises --html_exercise_icon=question_blue_on_white1.png --html_exercise_icon_width=80 --figure_prefix="https://raw.github.com/hplgit/doconce/master/test/" --movie_prefix="https://raw.github.com/hplgit/doconce/master/test/" --html_links_in_new_window --cite_doconce --html_raw_github_url=raw.github
 
 cp testdoc.html testdoc_wordpress.html
 
-system doconce format html testdoc --without_answers --without_solutions --examples_as_exercises -DSOMEVAR --html_exercise_icon=default --solutions_at_end --html_share=https://cyber.space.com/specials,twitter,print,google+,facebook,linkedin $rawgit
-system doconce format html testdoc --without_answers --without_solutions --examples_as_exercises --html_exercise_icon=default --answers_at_end --solutions_at_end --html_share=https://cyber.space.com/specials,twitter,print,google+,facebook,linkedin $rawgit
+system doconce format html testdoc --without_answers --without_solutions --examples_as_exercises -DSOMEVAR --html_exercise_icon=default --solutions_at_end --html_share=https://cyber.space.com/specials,twitter,print,google+,facebook,linkedin --html_raw_github_url=raw.github
+system doconce format html testdoc --without_answers --without_solutions --examples_as_exercises --html_exercise_icon=default --answers_at_end --solutions_at_end --html_share=https://cyber.space.com/specials,twitter,print,google+,facebook,linkedin --html_raw_github_url=raw.github
 
 system doconce split_html testdoc.html --method=space10
 cp testdoc.html testdoc_no_solutions.html
@@ -63,19 +61,19 @@ system doconce format latex testdoc --without_answers --without_solutions --exam
 cp testdoc.p.tex testdoc_no_solutions.p.tex
 
 cp ../bundled/html_styles/style_vagrant/template_vagrant.html .
-system doconce format html testdoc.do.txt --examples_as_exercises --html_style=bootstrap --html_template=template_vagrant.html --html_toc_indent=0 --toc_depth=2 $rawgit
+system doconce format html testdoc.do.txt --examples_as_exercises --html_style=bootstrap --html_template=template_vagrant.html --html_toc_indent=0 --toc_depth=2 --html_raw_github_url=raw.github
 cp testdoc.html testdoc_vagrant.html
 # Test that a split of testdoc_vagrant.html becomes correct
 doconce split_html testdoc_vagrant.html --method=split
 
 system doconce apply_inline_edits testdoc.do.txt
-system doconce format html testdoc.do.txt --pygments_html_linenos --html_style=solarized --pygments_html_style=emacs --examples_as_exercises --html_exercise_icon=exercise1.svg $rawgit
+system doconce format html testdoc.do.txt --pygments_html_linenos --html_style=solarized --pygments_html_style=emacs --examples_as_exercises --html_exercise_icon=exercise1.svg --html_raw_github_url=raw.github
 
 system doconce remove_exercise_answers testdoc.html
 system doconce html_colorbullets testdoc.html
 system doconce split_html testdoc.html --nav_button=gray2,bottom --font_size=slides
 
-system doconce format html testdoc.do.txt --pygments_html_linenos --html_style=solarized --pygments_html_style=emacs --examples_as_exercises --html_output=demo_testdoc $rawgit
+system doconce format html testdoc.do.txt --pygments_html_linenos --html_style=solarized --pygments_html_style=emacs --examples_as_exercises --html_output=demo_testdoc --html_raw_github_url=raw.github
 
 system doconce format latex testdoc.do.txt --examples_as_exercises SOMEVAR=True --skip_inline_comments --latex_packages=varioref
 
@@ -138,7 +136,7 @@ rm -rf standalone_exercises
 unzip testdoc_exercises.zip
 
 # Test prefix
-system doconce format html testdoc --code_prefix=https://raw.githubusercontent.com/hplgit/doconce/master/test --html_output=testdoc_code_prefix --examples_as_exercises
+system doconce format html testdoc --code_prefix=$PWD --html_output=testdoc_code_prefix --examples_as_exercises
 
 system doconce format plain testdoc.do.txt --examples_as_exercises -DSOMEVAR=1 --tables2csv
 system doconce format st testdoc.do.txt --examples_as_exercises
@@ -192,7 +190,7 @@ system doconce format pandoc testdoc.do.txt --examples_as_exercises
 # slides2: much of scientific_writing.do.txt
 # slides3: equal to slides/demo.do.txt
 
-system doconce format html slides1 --pygments_html_style=perldoc --keep_pygments_html_bg $rawgit
+system doconce format html slides1 --pygments_html_style=perldoc --keep_pygments_html_bg --html_raw_github_url=raw.github
 cp slides1.html slides1_1st.html  # before running slides_html
 
 system doconce slides_html slides1 reveal --html_slide_themee=simple
@@ -200,7 +198,7 @@ system doconce slides_html slides1 reveal --html_slide_themee=simple
 cp slides1.html slides1_reveal.html
 /bin/ls -R reveal.js >> slides1_reveal.html
 
-system doconce format html slides1 --pygments_html_style=emacs --keep_pygments_html_bg $rawgit
+system doconce format html slides1 --pygments_html_style=emacs --keep_pygments_html_bg --html_raw_github_url=raw.github
 system doconce slides_html slides1 deck --html_slide_theme=web-2.0
 
 cp slides1.html slides1_deck.html
@@ -223,7 +221,7 @@ system doconce format pdflatex slides1 --latex_title_layout=beamer "--latex_code
 system doconce slides_beamer slides1 --beamer_slide_theme=blue_shadow
 system pdflatex -shell-escape slides1
 
-doconce format html slides2 --pygments_html_style=emacs $rawgit --no_abort
+doconce format html slides2 --pygments_html_style=emacs --html_raw_github_url=raw.github --no_abort
 system doconce slides_html slides2 reveal --html_slide_theme=beigesmall
 cp slides2.html slides2_reveal.html
 
@@ -232,11 +230,11 @@ system doconce format pdflatex slides2 --latex_title_layout=beamer -DBEAMER --no
 system doconce ptex2tex slides2 envir=minted
 system doconce slides_beamer slides2
 
-system doconce format html slides3 --pygments_html_style=emacs SLIDE_TYPE=reveal SLIDE_THEME=beigesmall $rawgit
+system doconce format html slides3 --pygments_html_style=emacs SLIDE_TYPE=reveal SLIDE_THEME=beigesmall --html_raw_github_url=raw.github
 system doconce slides_html slides3 reveal --html_slide_type=beigesmall
 cp slides3.html slides3_reveal.html
 
-system doconce format html slides3 --html_style=solarized3 SLIDE_TYPE=doconce SLIDE_THEME=solarized3 --html_output=slides3-solarized3 $rawgit
+system doconce format html slides3 --html_style=solarized3 SLIDE_TYPE=doconce SLIDE_THEME=solarized3 --html_output=slides3-solarized3 --html_raw_github_url=raw.github
 system doconce slides_html slides3-solarized3 doconce --nav_button=bigblue,bottom --font_size=slides
 
 rm -f *.aux
@@ -245,7 +243,7 @@ system doconce format pdflatex slides3 SLIDE_TYPE=beamer SLIDE_THEME=$theme --la
 system doconce ptex2tex slides3 envir=minted
 system doconce slides_beamer slides3 --beamer_slide_theme=$theme
 
-system doconce format html slides1 --pygments_html_style=emacs $rawgit
+system doconce format html slides1 --pygments_html_style=emacs --html_raw_github_url=raw.github
 system doconce slides_html slides1 all
 
 # Test grab
@@ -254,13 +252,13 @@ doconce grab --from 'Compute a Probability' --to- 'drawing uniformly' _testdoc.d
 doconce grab --from- '\*\s+\$.+normally' _testdoc.do.txt >> testdoc.tmp
 
 # Test html templates
-system doconce format html html_template --html_template=template1.html --pygments_html_style=none $rawgit
+system doconce format html html_template --html_template=template1.html --pygments_html_style=none --html_raw_github_url=raw.github
 cp html_template.html html_template1.html
 
-system doconce format html html_template --html_template=template_inf1100.html  --pygments_html_style=emacs $rawgit
+system doconce format html html_template --html_template=template_inf1100.html  --pygments_html_style=emacs --html_raw_github_url=raw.github
 
 # Test author special case and generalized references
-system doconce format html author1 $rawgit
+system doconce format html author1 --html_raw_github_url=raw.github
 system doconce format latex author1
 system doconce format sphinx author1
 system doconce format plain author1
@@ -281,7 +279,11 @@ doconce ipynb2doconce nbdemo.ipynb
 
 # Test notebook execution
 doconce format ipynb execute.do.txt --examples_as_exercises
-doconce format ipynb execute.do.txt --execute --examples_as_exercises
+doconce format ipynb execute.do.txt --examples_as_exercises --execute 
+doconce format latex execute.do.txt --examples_as_exercises
+doconce format latex execute.do.txt --examples_as_exercises --execute 
+doconce format html execute.do.txt  --examples_as_exercises
+doconce format html execute.do.txt  --examples_as_exercises --execute 
 
 # Test math
 rm -f *.aux
@@ -289,7 +291,7 @@ name=math_test
 doconce format pdflatex $name --no_abort
 doconce ptex2tex $name
 pdflatex $name
-system doconce format html $name $rawgit --no_abort
+system doconce format html $name --html_raw_github_url=raw.github --no_abort
 cp $name.html ${name}_html.html
 doconce format sphinx $name --no_abort
 doconce sphinx_dir dirname=sphinx-rootdir-math $name
@@ -350,32 +352,32 @@ cp admon.tex admon_double_envirs.tex
 rm -rf latex_figs
 
 # Test HTML admon styles
-system doconce format html admon --html_admon=lyx --html_style=blueish2 --cite_doconce $rawgit
+system doconce format html admon --html_admon=lyx --html_style=blueish2 --cite_doconce --html_raw_github_url=raw.github
 cp admon.html admon_lyx.html
 
-system doconce format html admon --html_admon=paragraph --html_style=blueish2 --cite_doconce $rawgit
+system doconce format html admon --html_admon=paragraph --html_style=blueish2 --cite_doconce --html_raw_github_url=raw.github
 cp admon.html admon_paragraph.html
 
-system doconce format html admon --html_admon=colors --cite_doconce $rawgit
+system doconce format html admon --html_admon=colors --cite_doconce --html_raw_github_url=raw.github
 cp admon.html admon_colors.html
 
-system doconce format html admon --html_admon=gray --html_style=blueish2 --html_admon_shadow --html_box_shadow --cite_doconce $rawgit
+system doconce format html admon --html_admon=gray --html_style=blueish2 --html_admon_shadow --html_box_shadow --cite_doconce --html_raw_github_url=raw.github
 cp admon.html admon_gray.html
 
-system doconce format html admon --html_admon=yellow --html_admon_shadow --html_box_shadow --cite_doconce $rawgit
+system doconce format html admon --html_admon=yellow --html_admon_shadow --html_box_shadow --cite_doconce --html_raw_github_url=raw.github
 cp admon.html admon_yellow.html
 
-system doconce format html admon --html_admon=apricot --html_style=solarized --cite_doconce $rawgit
+system doconce format html admon --html_admon=apricot --html_style=solarized --cite_doconce --html_raw_github_url=raw.github
 cp admon.html admon_apricot.html
 
-system doconce format html admon --html_style=bootstrap --pygments_html_style=default --html_template=template_vagrant.html --cite_doconce $rawgit
+system doconce format html admon --html_style=bootstrap --pygments_html_style=default --html_template=template_vagrant.html --cite_doconce --html_raw_github_url=raw.github
 cp admon.html admon_vagrant.html
 
-system doconce format html admon --html_style=bootstrap --pygments_html_style=default --html_admon=bootstrap_alert --cite_doconce "--html_bootstrap_navbar_links=Google|https://google.com;DocOnce formats|https://hplgit.github.io/teamods/writing_reports/index.html" $rawgit
+system doconce format html admon --html_style=bootstrap --pygments_html_style=default --html_admon=bootstrap_alert --cite_doconce "--html_bootstrap_navbar_links=Google|https://google.com;DocOnce formats|https://hplgit.github.io/teamods/writing_reports/index.html" --html_raw_github_url=raw.github
 cp admon.html admon_bootstrap_alert.html
 doconce split_html admon_bootstrap_alert.html --pagination --nav_button=top+bottom
 
-system doconce format html admon --html_style=bootswatch --pygments_html_style=default --html_admon=bootstrap_panel --cite_doconce $rawgit
+system doconce format html admon --html_style=bootswatch --pygments_html_style=default --html_admon=bootstrap_panel --cite_doconce --html_raw_github_url=raw.github
 cp admon.html admon_bootswatch_panel.html
 
 system doconce sphinx_dir dirname=tmp_admon admon
@@ -404,20 +406,20 @@ if [ -d latex_figs ]; then
 fi
 
 # Test Bootstrap HTML styles
-system doconce format html test_boots --html_style=bootswatch_journal --pygments_html_style=default --html_admon=bootstrap_panel --html_code_style=inherit $rawgit
+system doconce format html test_boots --html_style=bootswatch_journal --pygments_html_style=default --html_admon=bootstrap_panel --html_code_style=inherit --html_raw_github_url=raw.github
 doconce split_html test_boots.html
 
 # Test GitHub-extended Markdown
 system doconce format pandoc github_md.do.txt --github_md
 
 # Test Markdown input
-doconce format html markdown_input.do.txt --markdown --md2do_output=mdinput2do.do.txt $rawgit
+doconce format html markdown_input.do.txt --markdown --md2do_output=mdinput2do.do.txt --html_raw_github_url=raw.github
 
 # Test movie handling
 name=movies
-system doconce format html $name --html_output=movies_3choices $rawgit
+system doconce format html $name --html_output=movies_3choices --html_raw_github_url=raw.github
 cp movies_3choices.html movie_demo
-system doconce format html $name --no_mp4_webm_ogg_alternatives $rawgit
+system doconce format html $name --no_mp4_webm_ogg_alternatives --html_raw_github_url=raw.github
 cp movies.html movie_demo
 
 rm -f $name.aux
@@ -463,7 +465,7 @@ doconce subst -m '^.*? (AM|PM) - ' '' automake_sphinx.log
 # in latex, media9 is unreliable
 
 # Test encoding: guess and change
-doconce format html encoding1   --no_header_footer $rawgit
+doconce format html encoding1   --no_header_footer --html_raw_github_url=raw.github
 system doconce guess_encoding encoding1.do.txt > tmp_encodings.txt
 cp encoding1.do.txt tmp1.do.txt
 system doconce change_encoding utf-8 latin1 tmp1.do.txt
@@ -480,16 +482,16 @@ doconce guess_encoding tmp2.do.txt >> tmp_encodings.txt
 doconce format latex encoding3 --debug --no_header_footer
 cp encoding3.p.tex encoding3.p.tex-ascii
 # Plain ASCII text with Norwegian chars coded as &#...;
-doconce format html encoding3 --pygments_html_style=off --debug --no_header_footer $rawgit
+doconce format html encoding3 --pygments_html_style=off --debug --no_header_footer --html_raw_github_url=raw.github
 cp encoding3.html encoding3.html-ascii
 cat _doconce_debugging.log >> encoding3.html-ascii
 
 # Plain ASCII with verbatim blocks with Norwegian chars
 doconce format latex encoding3 -DPREPROCESS --no_header_footer  # preprocess handles utf-8
 cp encoding3.p.tex encoding3.p.tex-ascii-verb
-doconce format html encoding3 -DPREPROCESS --no_header_footer  $rawgit # html fails with utf-8 in !bc
+doconce format html encoding3 -DPREPROCESS --no_header_footer  --html_raw_github_url=raw.github # html fails with utf-8 in !bc
 # Unicode with Norwegian chars in plain text and verbatim blocks
-doconce format html encoding3 -DPREPROCESS  --encoding=utf-8  --pygments_html_style=none --debug --no_header_footer $rawgit # Keeps Norwegian chars since output is in utf-8
+doconce format html encoding3 -DPREPROCESS  --encoding=utf-8  --pygments_html_style=none --debug --no_header_footer --html_raw_github_url=raw.github # Keeps Norwegian chars since output is in utf-8
 cp encoding3.html encoding3.html-ascii-verb
 cat _doconce_debugging.log >> encoding3.html-ascii-verb
 
@@ -497,17 +499,17 @@ doconce format latex encoding3 -DMAKO --no_header_footer  # mako fails due to No
 # Unicode with Norwegian chars in plain text and verbatim blocks
 doconce format latex encoding3 -DMAKO --encoding=utf-8 --no_header_footer  # utf-8 and unicode
 cp encoding3.p.tex encoding3.p.tex-utf8
-doconce format html encoding3 -DMAKO --encoding=utf-8 --pygments_html_style=off --debug --no_header_footer $rawgit
+doconce format html encoding3 -DMAKO --encoding=utf-8 --pygments_html_style=off --debug --no_header_footer --html_raw_github_url=raw.github
 cp encoding3.html encoding3.html-utf8
 cat _doconce_debugging.log >> encoding3.html-utf8
 
 # Test mako problems
-system doconce format html mako_test1 --pygments_html_style=off  --no_header_footer $rawgit  # mako variable only, no % lines
-system doconce format html mako_test2 --pygments_html_style=off  --no_header_footer $rawgit  # % lines inside code, but need for mako
-system doconce format html mako_test3 --pygments_html_style=off  --no_header_footer $rawgit  # % lines inside code
+system doconce format html mako_test1 --pygments_html_style=off  --no_header_footer --html_raw_github_url=raw.github  # mako variable only, no % lines
+system doconce format html mako_test2 --pygments_html_style=off  --no_header_footer --html_raw_github_url=raw.github  # % lines inside code, but need for mako
+system doconce format html mako_test3 --pygments_html_style=off  --no_header_footer --html_raw_github_url=raw.github  # % lines inside code
 cp mako_test3.html mako_test3b.html
-system doconce format html mako_test3 --pygments_html_style=none  --no_header_footer $rawgit # no problem message
-system doconce format html mako_test4 --pygments_html_style=no  --no_header_footer $rawgit   # works fine, lines start with %%
+system doconce format html mako_test3 --pygments_html_style=none  --no_header_footer --html_raw_github_url=raw.github # no problem message
+system doconce format html mako_test4 --pygments_html_style=no  --no_header_footer --html_raw_github_url=raw.github   # works fine, lines start with %%
 
 system doconce csv2table testtable.csv > testtable.do.txt
 
@@ -540,11 +542,11 @@ doconce replace 'doc/manual' 'doc/src/manual' tmp2.do.txt
 doconce format sphinx tmp2
 doconce replace '../lib/doconce/doconce.py' '_static/doconce.py' tmp2.do.txt
 doconce replace 'two_media99' 'two_media' tmp2.do.txt
-doconce format html tmp2 $rawgit
+doconce format html tmp2 --html_raw_github_url=raw.github
 doconce replace '|--l---|---l---|' '|--l-------l---|' tmp2.do.txt
-doconce format html tmp2 $rawgit
+doconce format html tmp2 --html_raw_github_url=raw.github
 doconce replace '99x9.ogg' '.ogg' tmp2.do.txt
-doconce format html tmp2 $rawgit
+doconce format html tmp2 --html_raw_github_url=raw.github
 doconce subst -s -m '^!bsol.+?!esol' ''  tmp2.do.txt
 doconce format sphinx tmp2
 doconce subst -s -m '^!bhint.+?!ehint' ''  tmp2.do.txt
@@ -556,9 +558,4 @@ doconce format pdflatex tmp2
 echo ""
 echo "When we reach this point in the script,"
 echo "it is clearly a successful run of all tests!"
-echo "Check the generated test.v file with e.g.: "
-echo "meld test.r test.v"
-echo "To remove untracked files run: "
-echo "cd .. & git clean -f -d"
-echo "rm -rf tmp_*"
 echo ""
